@@ -103,6 +103,7 @@ class Diff
     Diff() = default;//We use defualt initialization force compiler to generate a default constructor
     Diff(LineCount eq, const qint64 inDiff1, const qint64 inDiff2)
     {
+        assert(eq >= 0);
         nofEquals = eq;
         mDiff1 = inDiff1;
         mDiff2 = inDiff2;
@@ -191,7 +192,7 @@ class ManualDiffHelpList; // A list of corresponding ranges
 class Diff3Line;
 class Diff3LineList;
 
-using Diff3LineVector = QVector<Diff3Line*>;
+using Diff3LineVector = QVector<std::shared_ptr<Diff3Line>>;
 
 class DiffBufferInfo
 {
@@ -438,7 +439,7 @@ struct HistoryRange
 
 struct Diff3WrapLine
 {
-    Diff3Line* pD3L = nullptr;
+    std::shared_ptr<Diff3Line> pD3L = nullptr;
     int diff3LineIndex = 0;
     int wrapLineOffset = 0;
     int wrapLineLength = 0;
