@@ -419,7 +419,10 @@ bool KDiff3App::doFileCompare()
     m_pDirectoryMergeInfoDock->hide();
 
     mainInit(m_totalDiffStatus);
-    if(m_bAutoMode)
+    if(m_totalDiffStatus->getUnsolvedConflicts() != 0)
+        bSuccess = false;
+
+    if(m_bAutoMode && m_totalDiffStatus->getUnsolvedConflicts() == 0)
     {
         QSharedPointer<SourceData> pSD = nullptr;
         if(m_sd3->isEmpty())
@@ -533,8 +536,12 @@ void KDiff3App::completeInit(const QString& fn1, const QString& fn2, const QStri
     }
 
     if(bSuccess && m_bAutoMode) return;
-    if(m_bAutoMode && !isPart()) showMainWindow();
-
+    if(m_bAutoMode && !isPart())
+    {
+        showMainWindow();
+        //Fire wordwrap recalc signal bypassed during auto-merge pass.
+        QMetaObject::invokeMethod(this, &KDiff3App::postRecalcWordWrap, Qt::QueuedConnection);
+    }
     m_bAutoMode = false;
 
     if(statusBar() != nullptr)
