@@ -3,7 +3,8 @@
  *
  * SPDX-FileCopyrightText: 2002-2011 Joachim Eibl, joachim.eibl at gmx.de
  * SPDX-License-Identifier: GPL-2.0-or-later
-*/
+ */
+// clang-format on
 
 #ifndef SMALLDIALOGS_H
 #define SMALLDIALOGS_H
@@ -15,7 +16,7 @@
 #include <QCheckBox>
 #include <QComboBox>
 #include <QDialog>
-#include <QPointer>
+#include <QSharedPointer>
 
 class Options;
 class QLineEdit;
@@ -39,13 +40,13 @@ class OpenDialog: public QDialog
         KDiff3App* pParent, const QString& n1, const QString& n2, const QString& n3,
         bool bMerge, const QString& outputName, const QSharedPointer<Options>& pOptions);
 
-    const QString getFileA() const { return dialogUi.lineA->currentText(); }
-    const QString getFileB() const { return dialogUi.lineB->currentText(); }
-    const QString getFileC() const { return dialogUi.lineC->currentText(); }
+    [[nodiscard]] const QString getFileA() const { return dialogUi.lineA->currentText(); }
+    [[nodiscard]] const QString getFileB() const { return dialogUi.lineB->currentText(); }
+    [[nodiscard]] const QString getFileC() const { return dialogUi.lineC->currentText(); }
 
-    const QString getOutputFile() const { return dialogUi.lineOut->currentText(); }
+    [[nodiscard]] const QString getOutputFile() const { return dialogUi.lineOut->currentText(); }
 
-    bool merge() const { return dialogUi.mergeCheckBox->isChecked(); }
+    [[nodiscard]] bool merge() const { return dialogUi.mergeCheckBox->isChecked(); }
 
     void accept() override;
   private:
